about summary refs log tree commit homepage
path: root/lib/unicorn/const.rb
diff options
context:
space:
mode:
authorEric Wong <normalperson@yhbt.net>2010-10-09 00:03:43 +0000
committerEric Wong <normalperson@yhbt.net>2010-10-09 00:03:43 +0000
commit2243c97edf80d635871bc678794f07d6c1d033c2 (patch)
tree1f32029c8883cb098555b53c6c8eee21709b09f2 /lib/unicorn/const.rb
parent6eb46e422f4b2ba98c795fca5e18e7262c0c688e (diff)
downloadunicorn-2243c97edf80d635871bc678794f07d6c1d033c2.tar.gz
There is a new Unicorn::PrereadInput middleware to which allows
input bodies to be drained off the socket and buffered to disk
(or memory) before dispatching the application.

HTTP Pipelining behavior is fixed for Rainbows!  There
are some small Kgio fixes and updates for Rainbows!
users as well.
Diffstat (limited to 'lib/unicorn/const.rb')
-rw-r--r--lib/unicorn/const.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/unicorn/const.rb b/lib/unicorn/const.rb
index 46f7d47..e7908d6 100644
--- a/lib/unicorn/const.rb
+++ b/lib/unicorn/const.rb
@@ -7,8 +7,8 @@
 # improve things much compared to constants.
 module Unicorn::Const
 
-  # The current version of Unicorn, currently 2.0.0pre2
-  UNICORN_VERSION = "2.0.0pre2"
+  # The current version of Unicorn, currently 2.0.0pre3
+  UNICORN_VERSION = "2.0.0pre3"
 
   # default TCP listen host address (0.0.0.0, all interfaces)
   DEFAULT_HOST = "0.0.0.0"